@@ -216,6 +216,7 @@ void KviTopicWidget::applyOptions()
 {
 	//set the font
 	m_pLabel->applyOptions();
+	m_pInput->applyOptions(true);
 	QFont newFont(KVI_OPTION_FONT(KviOption_fontLabel));
 	newFont.setKerning(false);
 	newFont.setHintingPreference(QFont::PreferFullHinting);
@@ -225,6 +226,7 @@ void KviTopicWidget::applyOptions()
 
 	// reset topic html too (in case colors have been changed)
 	m_pLabel->setText(KviHtmlGenerator::convertToHtml(m_szTopic, true));
+	setFixedHeight(m_pInput->heightHint());
 }
 
 static bool isKviControlCode(unsigned short c)
@@ -234,6 +236,7 @@ static bool isKviControlCode(unsigned short c)
 	case KviControlCodes::Bold:
 	case KviControlCodes::Italic:
 	case KviControlCodes::Underline:
+	case KviControlCodes::Monospace:
 	case KviControlCodes::Reverse:
 	case KviControlCodes::Reset:
 	case KviControlCodes::Icon:
@@ -249,6 +252,7 @@ void KviTopicWidget::paintColoredText(QPainter * p, QString text, const QPalette
 	bool curBold = false;
 	bool curItalic = false;
 	bool curUnderline = false;
+	bool curMonospace = false;
 	unsigned char curFore = KVI_LABEL_DEF_FORE; //default fore
 	unsigned char curBack = KVI_LABEL_DEF_BACK; //default back
 	int baseline = rect.top() + rect.height() - fm.descent() - 1;
@@ -342,6 +346,10 @@ void KviTopicWidget::paintColoredText(QPainter * p, QString text, const QPalette
 				curUnderline = !curUnderline;
 				++idx;
 				break;
+			case KviControlCodes::Monospace:
+				curMonospace = !curMonospace;
+				++idx;
+				break;
 			case KviControlCodes::Reverse:
 			{
 				char auxBack = curBack;
@@ -744,6 +752,9 @@ QChar KviTopicWidget::getSubstituteChar(unsigned short control_code)
 		case KviControlCodes::Italic:
 			return QChar('I');
 			break;
+		case KviControlCodes::Monospace:
+			return QChar('M');
+			break;
 		case KviControlCodes::Reset:
 			return QChar('O');
 			break;
